@@ -22,15 +22,20 @@ reconnaissance of remote hosts.
 
 class ReconLibException(Exception):
     def __init__(self, message: str, code: int):
-        self.message = message
+        super().__init__(f"{self.__class__.__name__}: {message}")
         self.code = code
 
 
 class InvalidTargetError(ReconLibException):
     def __init__(self, message: str, code: int = 1):
-        super().__init__(f"{self.__class__.__name__}: {message}", code)
+        super().__init__(message, code)
 
 
 class APIKeyError(ReconLibException):
     def __init__(self, message: str, code: int = 1):
-        super().__init__(f"{self.__class__.__name__}: {message}", code)
+        super().__init__(message, code)
+
+
+class APIQuotaUsageError(ReconLibException):
+    def __init__(self, message: str, code: int = 1):
+        super().__init__(message, code)
